=== modified file 'drizzled/common.h'
--- drizzled/common.h	2010-12-24 06:48:40 +0000
+++ drizzled/common.h	2011-01-04 04:05:27 +0000
@@ -192,9 +192,10 @@
                         DRIZZLE_TYPE_BLOB,
                         DRIZZLE_TYPE_TIME,
                         DRIZZLE_TYPE_BOOLEAN,
-                        DRIZZLE_TYPE_UUID
+                        DRIZZLE_TYPE_UUID,
+                        DRIZZLE_TYPE_MICROTIME
 };
-const int enum_field_types_size= DRIZZLE_TYPE_UUID + 1;
+const int enum_field_types_size= DRIZZLE_TYPE_MICROTIME + 1;
 
 } /* namespace drizzled */
 

=== modified file 'drizzled/create_field.cc'
--- drizzled/create_field.cc	2010-12-25 00:28:49 +0000
+++ drizzled/create_field.cc	2011-01-04 04:05:27 +0000
@@ -102,7 +102,7 @@
   if (!(flags & (NO_DEFAULT_VALUE_FLAG)) &&
       !(flags & AUTO_INCREMENT_FLAG) &&
       old_field->ptr && orig_field &&
-      (sql_type != DRIZZLE_TYPE_TIMESTAMP ||                /* set def only if */
+      (not old_field->is_timestamp() ||                /* set def only if */
        old_field->getTable()->timestamp_field != old_field ||  /* timestamp field */
        unireg_check == Field::TIMESTAMP_UN_FIELD))        /* has default val */
   {
@@ -227,8 +227,10 @@
     it is NOT NULL, not an AUTO_INCREMENT field and not a TIMESTAMP.
   */
   if (!fld_default_value && !(fld_type_modifier & AUTO_INCREMENT_FLAG) &&
-      (fld_type_modifier & NOT_NULL_FLAG) && fld_type != DRIZZLE_TYPE_TIMESTAMP)
+      (fld_type_modifier & NOT_NULL_FLAG) && (fld_type != DRIZZLE_TYPE_TIMESTAMP and fld_type != DRIZZLE_TYPE_MICROTIME))
+  {
     flags|= NO_DEFAULT_VALUE_FLAG;
+  }
 
   if (fld_length && !(length= (uint32_t) atoi(fld_length)))
     fld_length= 0;
@@ -300,8 +302,9 @@
         return(true);
       }
       break;
+    case DRIZZLE_TYPE_MICROTIME:
     case DRIZZLE_TYPE_TIMESTAMP:
-      if (!fld_length)
+      if (not fld_length)
       {
         length= DateTime::MAX_STRING_LENGTH;
       }
@@ -328,8 +331,10 @@
           def= 0;
         }
         else
+        {
           unireg_check= (fld_on_update_value ? Field::TIMESTAMP_UN_FIELD:
-                                              Field::NONE);
+                         Field::NONE);
+        }
       }
       else
       {

=== modified file 'drizzled/definition/table.cc'
--- drizzled/definition/table.cc	2010-12-30 18:10:25 +0000
+++ drizzled/definition/table.cc	2011-01-04 04:05:27 +0000
@@ -78,6 +78,7 @@
 #include "drizzled/field/time.h"
 #include "drizzled/field/epoch.h"
 #include "drizzled/field/datetime.h"
+#include "drizzled/field/microtime.h"
 #include "drizzled/field/varstring.h"
 #include "drizzled/field/uuid.h"
 
@@ -321,6 +322,7 @@
   case DRIZZLE_TYPE_DATE:
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_MICROTIME:
   case DRIZZLE_TYPE_BOOLEAN:
     default_item= new Item_string(default_value->c_str(),
                                   default_value->length(),
@@ -1316,7 +1318,10 @@
       }
       break;
     case DRIZZLE_TYPE_LONGLONG:
-      field_length= MAX_BIGINT_WIDTH;
+      {
+        uint32_t sign_len= pfield.constraints().is_unsigned() ? 0 : 1;
+        field_length= MAX_BIGINT_WIDTH+sign_len;
+      }
       break;
     case DRIZZLE_TYPE_UUID:
       field_length= field::Uuid::max_string_length();
@@ -1324,6 +1329,9 @@
     case DRIZZLE_TYPE_BOOLEAN:
       field_length= field::Boolean::max_string_length();
       break;
+    case DRIZZLE_TYPE_MICROTIME:
+      field_length= field::Microtime::max_string_length();
+      break;
     case DRIZZLE_TYPE_TIMESTAMP:
       field_length= field::Epoch::max_string_length();
       break;
@@ -1334,8 +1342,6 @@
       abort(); // Programming error
     }
 
-    assert(enum_field_types_size == 14);
-
     Field* f= make_field(pfield,
                          record + field_offsets[fieldnr] + data_offset,
                          field_length,
@@ -1361,6 +1367,7 @@
     case DRIZZLE_TYPE_TIMESTAMP:
     case DRIZZLE_TYPE_TIME:
     case DRIZZLE_TYPE_DATETIME:
+    case DRIZZLE_TYPE_MICROTIME:
     case DRIZZLE_TYPE_DATE:
     case DRIZZLE_TYPE_ENUM:
     case DRIZZLE_TYPE_LONG:
@@ -1416,10 +1423,10 @@
 
     f->setPosition(fieldnr);
     f->comment= comment;
-    if (! default_value &&
-        ! (f->unireg_check==Field::NEXT_NUMBER) &&
+    if (not default_value &&
+        not (f->unireg_check==Field::NEXT_NUMBER) &&
         (f->flags & NOT_NULL_FLAG) &&
-        (f->real_type() != DRIZZLE_TYPE_TIMESTAMP))
+        (not f->is_timestamp()))
     {
       f->flags|= NO_DEFAULT_VALUE_FLAG;
     }
@@ -2082,7 +2089,6 @@
   {
   case DRIZZLE_TYPE_DATE:
   case DRIZZLE_TYPE_DATETIME:
-  case DRIZZLE_TYPE_TIMESTAMP:
   case DRIZZLE_TYPE_UUID:
     field_charset= &my_charset_bin;
   default: break;
@@ -2171,15 +2177,20 @@
                                           unireg_check,
                                           field_name);
     }
+  case DRIZZLE_TYPE_MICROTIME:
+    return new (&mem_root) field::Microtime(ptr,
+                                            null_pos,
+                                            null_bit,
+                                            unireg_check,
+                                            field_name,
+                                            this);
   case DRIZZLE_TYPE_TIMESTAMP:
     return new (&mem_root) field::Epoch(ptr,
-                                        field_length,
                                         null_pos,
                                         null_bit,
                                         unireg_check,
                                         field_name,
-                                        this,
-                                        field_charset);
+                                        this);
   case DRIZZLE_TYPE_TIME:
     return new (&mem_root) field::Time(ptr,
                                        field_length,

=== modified file 'drizzled/display.cc'
--- drizzled/display.cc	2010-12-30 04:59:36 +0000
+++ drizzled/display.cc	2011-01-04 04:05:27 +0000
@@ -43,6 +43,7 @@
 static const std::string DRIZZLE_TYPE_DOUBLE("DRIZZLE_TYPE_DOUBLE"); 
 static const std::string DRIZZLE_TYPE_NULL("DRIZZLE_TYPE_NULL"); 
 static const std::string DRIZZLE_TYPE_TIMESTAMP("DRIZZLE_TYPE_TIMESTAMP"); 
+static const std::string DRIZZLE_TYPE_MICROTIME("DRIZZLE_TYPE_MICROTIME"); 
 static const std::string DRIZZLE_TYPE_LONGLONG("DRIZZLE_TYPE_LONGLONG"); 
 static const std::string DRIZZLE_TYPE_DATETIME("DRIZZLE_TYPE_DATETIME"); 
 static const std::string DRIZZLE_TYPE_TIME("DRIZZLE_TYPE_TIME"); 
@@ -239,6 +240,8 @@
     return DRIZZLE_TYPE_DOUBLE;
   case drizzled::DRIZZLE_TYPE_NULL : 
     return DRIZZLE_TYPE_NULL;
+  case drizzled::DRIZZLE_TYPE_MICROTIME : 
+    return DRIZZLE_TYPE_MICROTIME;
   case drizzled::DRIZZLE_TYPE_TIMESTAMP : 
     return DRIZZLE_TYPE_TIMESTAMP;
   case drizzled::DRIZZLE_TYPE_LONGLONG : 

=== modified file 'drizzled/field.cc'
--- drizzled/field.cc	2010-12-26 08:07:57 +0000
+++ drizzled/field.cc	2011-01-04 04:05:27 +0000
@@ -45,6 +45,7 @@
 #include "drizzled/field/time.h"
 #include "drizzled/field/epoch.h"
 #include "drizzled/field/datetime.h"
+#include "drizzled/field/microtime.h"
 #include "drizzled/field/varstring.h"
 #include "drizzled/field/uuid.h"
 #include "drizzled/time_functions.h"
@@ -92,6 +93,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_DOUBLE -> */
   {
@@ -123,6 +126,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_NULL -> */
   {
@@ -154,6 +159,8 @@
     DRIZZLE_TYPE_BOOLEAN,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_UUID,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_MICROTIME,
   },
   /* DRIZZLE_TYPE_TIMESTAMP -> */
   {
@@ -185,6 +192,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_LONGLONG -> */
   {
@@ -215,6 +224,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_DATETIME -> */
   {
@@ -246,6 +257,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_DATE -> */
   {
@@ -277,6 +290,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_VARCHAR -> */
   {
@@ -308,6 +323,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_DECIMAL -> */
   {
@@ -339,6 +356,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_ENUM -> */
   {
@@ -370,6 +389,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
    },
   /* DRIZZLE_TYPE_BLOB -> */
   {
@@ -401,6 +422,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_TIME -> */
   {
@@ -432,6 +455,8 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_UUID,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_BOOLEAN -> */
   {
@@ -463,6 +488,8 @@
     DRIZZLE_TYPE_BOOLEAN,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
   },
   /* DRIZZLE_TYPE_UUID -> */
   {
@@ -494,6 +521,41 @@
     DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_UUID,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_VARCHAR,
+  },
+  /* DRIZZLE_TYPE_MICROTIME -> */
+  {
+    //DRIZZLE_TYPE_LONG
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DOUBLE
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_NULL
+    DRIZZLE_TYPE_MICROTIME,
+    //DRIZZLE_TYPE_TIMESTAMP
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_LONGLONG
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DATETIME
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DATE
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_VARCHAR
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DECIMAL
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_VARCHAR,
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_BLOB
+    DRIZZLE_TYPE_BLOB,
+    //DRIZZLE_TYPE_TIME
+    DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_UUID
+    DRIZZLE_TYPE_UUID,
+    //DRIZZLE_TYPE_MICROTIME
+    DRIZZLE_TYPE_MICROTIME,
   },
 };
 
@@ -527,6 +589,8 @@
   STRING_RESULT,
   //DRIZZLE_TYPE_UUID
   STRING_RESULT,
+  //DRIZZLE_TYPE_MICROTIME
+  STRING_RESULT,
 };
 
 bool test_if_important_data(const CHARSET_INFO * const cs, 
@@ -1047,17 +1111,22 @@
 {
   if (!Field::eq_def(field))
     return 0;
+
   TYPELIB *from_lib=((Field_enum*) field)->typelib;
 
   if (typelib->count < from_lib->count)
     return 0;
+
   for (uint32_t i=0 ; i < from_lib->count ; i++)
+  {
     if (my_strnncoll(field_charset,
                      (const unsigned char*)typelib->type_names[i],
                      strlen(typelib->type_names[i]),
                      (const unsigned char*)from_lib->type_names[i],
                      strlen(from_lib->type_names[i])))
       return 0;
+  }
+
   return 1;
 }
 
@@ -1066,6 +1135,8 @@
   switch (type) {
   case DRIZZLE_TYPE_VARCHAR: return (length + (length < 256 ? 1: 2));
   case DRIZZLE_TYPE_UUID: return field::Uuid::max_string_length();
+  case DRIZZLE_TYPE_MICROTIME: return field::Microtime::max_string_length();
+  case DRIZZLE_TYPE_TIMESTAMP: return field::Epoch::max_string_length();
   case DRIZZLE_TYPE_BOOLEAN: return field::Boolean::max_string_length();
   case DRIZZLE_TYPE_DATE:
   case DRIZZLE_TYPE_ENUM:
@@ -1073,7 +1144,6 @@
   case DRIZZLE_TYPE_DOUBLE: return sizeof(double);
   case DRIZZLE_TYPE_TIME:
   case DRIZZLE_TYPE_DATETIME:
-  case DRIZZLE_TYPE_TIMESTAMP:
   case DRIZZLE_TYPE_LONGLONG: return 8;	/* Don't crash if no int64_t */
   case DRIZZLE_TYPE_NULL: return 0;
   case DRIZZLE_TYPE_BLOB: return 4 + portable_sizeof_char_ptr;

=== modified file 'drizzled/field.h'
--- drizzled/field.h	2010-12-27 19:18:58 +0000
+++ drizzled/field.h	2011-01-04 04:05:27 +0000
@@ -286,6 +286,11 @@
    */
   virtual bool eq_def(Field *field);
 
+  virtual bool is_timestamp() const
+  {
+    return false;
+  }
+
   /**
    * Returns size (in bytes) used to store field data in memory
    * (i.e. it returns the maximum size of the field in a row of the table,

=== modified file 'drizzled/field/epoch.cc'
--- drizzled/field/epoch.cc	2010-12-25 04:38:28 +0000
+++ drizzled/field/epoch.cc	2011-01-04 04:05:27 +0000
@@ -82,19 +82,17 @@
   exception is different behavior of old/new timestamps during ALTER TABLE.
  */
   Epoch::Epoch(unsigned char *ptr_arg,
-               uint32_t,
                unsigned char *null_ptr_arg,
                unsigned char null_bit_arg,
                enum utype unireg_check_arg,
                const char *field_name_arg,
-               drizzled::TableShare *share,
-               const drizzled::CHARSET_INFO * const cs) :
+               drizzled::TableShare *share) :
   Field_str(ptr_arg,
             DateTime::MAX_STRING_LENGTH - 1 /* no \0 */,
             null_ptr_arg,
             null_bit_arg,
             field_name_arg,
-            cs)
+            &my_charset_bin)
 {
   unireg_check= unireg_check_arg;
   if (! share->getTimestampField() && unireg_check != NONE)
@@ -108,14 +106,13 @@
 }
 
 Epoch::Epoch(bool maybe_null_arg,
-             const char *field_name_arg,
-             const CHARSET_INFO * const cs) :
+             const char *field_name_arg) :
   Field_str((unsigned char*) NULL,
             DateTime::MAX_STRING_LENGTH - 1 /* no \0 */,
             maybe_null_arg ? (unsigned char*) "": 0,
             0,
             field_name_arg,
-            cs)
+            &my_charset_bin)
 {
   if (unireg_check != TIMESTAMP_DN_FIELD)
     flags|= ON_UPDATE_NOW_FLAG;

=== modified file 'drizzled/field/epoch.h'
--- drizzled/field/epoch.h	2010-12-25 04:38:28 +0000
+++ drizzled/field/epoch.h	2011-01-04 04:05:27 +0000
@@ -38,17 +38,14 @@
   typedef Epoch* pointer;
 
   Epoch(unsigned char *ptr_arg,
-        uint32_t len_arg,
         unsigned char *null_ptr_arg,
         unsigned char null_bit_arg,
         enum utype unireg_check_arg,
         const char *field_name_arg,
-        drizzled::TableShare *share,
-        const drizzled::CHARSET_INFO * const cs);
+        drizzled::TableShare *share);
 
   Epoch(bool maybe_null_arg,
-        const char *field_name_arg,
-        const CHARSET_INFO * const cs);
+        const char *field_name_arg);
 
   enum_field_types type() const { return DRIZZLE_TYPE_TIMESTAMP;}
   enum ha_base_keytype key_type() const { return HA_KEYTYPE_ULONGLONG; }
@@ -73,6 +70,11 @@
   /* Get TIMESTAMP field value as seconds since begging of Unix Epoch */
   long get_timestamp(bool *null_value);
 
+  virtual bool is_timestamp() const
+  {
+    return true;
+  }
+
 private:
   bool get_date(type::Time *ltime,uint32_t fuzzydate);
   bool get_time(type::Time *ltime);

=== added file 'drizzled/field/microtime.cc'
--- drizzled/field/microtime.cc	1970-01-01 00:00:00 +0000
+++ drizzled/field/microtime.cc	2011-01-04 04:05:27 +0000
@@ -0,0 +1,298 @@
+/* -*- mode: c++ c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include <boost/lexical_cast.hpp>
+#include <drizzled/field/microtime.h>
+#include <drizzled/error.h>
+#include <drizzled/tztime.h>
+#include <drizzled/table.h>
+#include <drizzled/session.h>
+
+#include <math.h>
+
+#include <sstream>
+
+#include "drizzled/temporal.h"
+
+namespace drizzled
+{
+
+namespace field
+{
+Microtime::Microtime(unsigned char *ptr_arg,
+                     unsigned char *null_ptr_arg,
+                     unsigned char null_bit_arg,
+                     enum utype unireg_check_arg,
+                     const char *field_name_arg,
+                     drizzled::TableShare *share) :
+  Epoch(ptr_arg,
+        null_ptr_arg,
+        null_bit_arg,
+        unireg_check_arg,
+        field_name_arg,
+        share)
+  {
+  }
+
+Microtime::Microtime(bool maybe_null_arg,
+                     const char *field_name_arg) :
+  Epoch(maybe_null_arg,
+        field_name_arg)
+{
+}
+
+/**
+  Get auto-set type for TIMESTAMP field.
+
+  Returns value indicating during which operations this TIMESTAMP field
+  should be auto-set to current timestamp.
+*/
+timestamp_auto_set_type Microtime::get_auto_set_type() const
+{
+  switch (unireg_check)
+  {
+  case TIMESTAMP_DN_FIELD:
+    return TIMESTAMP_AUTO_SET_ON_INSERT;
+  case TIMESTAMP_UN_FIELD:
+    return TIMESTAMP_AUTO_SET_ON_UPDATE;
+  case TIMESTAMP_OLD_FIELD:
+    /*
+      Although we can have several such columns in legacy tables this
+      function should be called only for first of them (i.e. the one
+      having auto-set property).
+    */
+    assert(getTable()->timestamp_field == this);
+    /* Fall-through */
+  case TIMESTAMP_DNUN_FIELD:
+    return TIMESTAMP_AUTO_SET_ON_BOTH;
+  default:
+    /*
+      Normally this function should not be called for TIMESTAMPs without
+      auto-set property.
+    */
+    assert(0);
+    return TIMESTAMP_NO_AUTO_SET;
+  }
+}
+
+int Microtime::store(const char *from,
+                 uint32_t len,
+                 const CHARSET_INFO * const )
+{
+  Timestamp temporal;
+
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+
+  if (not temporal.from_string(from, (size_t) len))
+  {
+    my_error(ER_INVALID_UNIX_TIMESTAMP_VALUE, MYF(ME_FATALERROR), from);
+    return 1;
+  }
+
+  time_t tmp;
+  temporal.to_time_t(tmp);
+
+  pack_num(tmp);
+  return 0;
+}
+
+int Microtime::store(double from)
+{
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+
+  if (from < 0 || from > 99991231235959.0)
+  {
+    /* Convert the double to a string using stringstream */
+    std::stringstream ss;
+    std::string tmp;
+    ss.precision(18); /* 18 places should be fine for error display of double input. */
+    ss << from; 
+    ss >> tmp;
+
+    my_error(ER_INVALID_UNIX_TIMESTAMP_VALUE, MYF(ME_FATALERROR), tmp.c_str());
+    return 2;
+  }
+  return Microtime::store((int64_t) rint(from), false);
+}
+
+int Microtime::store(int64_t from, bool)
+{
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+
+  /* 
+   * Try to create a DateTime from the supplied integer.  Throw an error
+   * if unable to create a valid DateTime.  
+   */
+  Timestamp temporal;
+  if (! temporal.from_int64_t(from))
+  {
+    /* Convert the integer to a string using boost::lexical_cast */
+    std::string tmp(boost::lexical_cast<std::string>(from));
+
+    my_error(ER_INVALID_UNIX_TIMESTAMP_VALUE, MYF(ME_FATALERROR), tmp.c_str());
+    return 2;
+  }
+
+  time_t tmp;
+  temporal.to_time_t(tmp);
+
+  pack_num(tmp);
+
+  return 0;
+}
+
+double Microtime::val_real(void)
+{
+  return (double) Microtime::val_int();
+}
+
+int64_t Microtime::val_int(void)
+{
+  uint64_t temp;
+
+  ASSERT_COLUMN_MARKED_FOR_READ;
+
+  unpack_num(temp);
+
+  Timestamp temporal;
+  (void) temporal.from_time_t((time_t) temp);
+
+  /* We must convert into a "timestamp-formatted integer" ... */
+  int64_t result;
+  temporal.to_int64_t(&result);
+  return result;
+}
+
+String *Microtime::val_str(String *val_buffer, String *)
+{
+  uint64_t temp= 0;
+  char *to;
+  int to_len= field_length + 1;
+
+  val_buffer->alloc(to_len);
+  to= (char *) val_buffer->ptr();
+
+  unpack_num(temp);
+
+  val_buffer->set_charset(&my_charset_bin);	/* Safety */
+
+  Timestamp temporal;
+  (void) temporal.from_time_t((time_t) temp);
+
+  int rlen;
+  rlen= temporal.to_string(to, to_len);
+  assert(rlen < to_len);
+
+  val_buffer->length(rlen);
+  return val_buffer;
+}
+
+bool Microtime::get_date(type::Time *ltime, uint32_t)
+{
+  uint64_t temp;
+
+  unpack_num(temp);
+  
+  memset(ltime, 0, sizeof(*ltime));
+
+  Timestamp temporal;
+  (void) temporal.from_time_t((time_t) temp);
+
+  /* @TODO Goodbye the below code when type::Time is finally gone.. */
+
+  ltime->time_type= DRIZZLE_TIMESTAMP_DATETIME;
+  ltime->year= temporal.years();
+  ltime->month= temporal.months();
+  ltime->day= temporal.days();
+  ltime->hour= temporal.hours();
+  ltime->minute= temporal.minutes();
+  ltime->second= temporal.seconds();
+
+  return 0;
+}
+
+bool Microtime::get_time(type::Time *ltime)
+{
+  return Microtime::get_date(ltime,0);
+}
+
+int Microtime::cmp(const unsigned char *a_ptr, const unsigned char *b_ptr)
+{
+  uint64_t a,b;
+
+  unpack_num(a, a_ptr);
+  unpack_num(b, b_ptr);
+
+  return (a < b) ? -1 : (a > b) ? 1 : 0;
+}
+
+
+void Microtime::sort_string(unsigned char *to,uint32_t )
+{
+#ifdef WORDS_BIGENDIAN
+  if ((not getTable()) or (not getTable()->getShare()->db_low_byte_first))
+  {
+    std::reverse_copy(to, to+pack_length(), ptr);
+  }
+  else
+#endif
+  {
+    memcpy(to, ptr, pack_length());
+  }
+}
+
+void Microtime::sql_type(String &res) const
+{
+  res.set_ascii(STRING_WITH_LEN("microtime"));
+}
+
+void Microtime::set_time()
+{
+  Session *session= getTable() ? getTable()->in_use : current_session;
+  time_t tmp= session->query_start();
+  set_notnull();
+  pack_num(tmp);
+}
+
+void Microtime::set_default()
+{
+  if (getTable()->timestamp_field == this &&
+      unireg_check != TIMESTAMP_UN_FIELD)
+  {
+    set_time();
+  }
+  else
+  {
+    Field::set_default();
+  }
+}
+
+long Microtime::get_timestamp(bool *null_value)
+{
+  if ((*null_value= is_null()))
+    return 0;
+
+  uint64_t tmp;
+  return unpack_num(tmp);
+}
+
+} /* namespace field */
+} /* namespace drizzled */

=== added file 'drizzled/field/microtime.h'
--- drizzled/field/microtime.h	1970-01-01 00:00:00 +0000
+++ drizzled/field/microtime.h	2011-01-04 04:05:27 +0000
@@ -0,0 +1,89 @@
+/* - mode: c++ c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 MySQL
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_FIELD_MICROTIME_H
+#define DRIZZLED_FIELD_MICROTIME_H
+
+#include <drizzled/field/epoch.h>
+
+namespace drizzled
+{
+
+namespace field
+{
+
+class TableShare;
+typedef struct charset_info_st CHARSET_INFO;
+
+class Microtime :public Epoch {
+public:
+
+  typedef Microtime* pointer;
+
+  Microtime(unsigned char *ptr_arg,
+            unsigned char *null_ptr_arg,
+            unsigned char null_bit_arg,
+            enum utype unireg_check_arg,
+            const char *field_name_arg,
+            drizzled::TableShare *share);
+
+  Microtime(bool maybe_null_arg,
+            const char *field_name_arg);
+
+  enum_field_types type() const { return DRIZZLE_TYPE_TIMESTAMP;}
+  enum ha_base_keytype key_type() const { return HA_KEYTYPE_ULONGLONG; }
+  enum Item_result cmp_type () const { return INT_RESULT; }
+  int  store(const char *to,uint32_t length,
+             const CHARSET_INFO * const charset);
+  int  store(double nr);
+  int  store(int64_t nr, bool unsigned_val);
+  int  reset(void) { memset(ptr, 0, max_string_length()); return 0; }
+  double val_real(void);
+  int64_t val_int(void);
+  String *val_str(String*,String *);
+  int cmp(const unsigned char *,const unsigned char *);
+  void sort_string(unsigned char *buff,uint32_t length);
+  uint32_t pack_length() const { return max_string_length(); }
+  void sql_type(String &str) const;
+  bool can_be_compared_as_int64_t() const { return false; }
+  bool zero_pack() const { return 0; }
+  void set_time();
+  virtual void set_default();
+
+  /* Get TIMESTAMP field value as seconds since begging of Unix Microtime */
+  long get_timestamp(bool *null_value);
+
+private:
+  bool get_date(type::Time *ltime,uint32_t fuzzydate);
+  bool get_time(type::Time *ltime);
+
+public:
+  timestamp_auto_set_type get_auto_set_type() const;
+  static size_t max_string_length()
+  {
+    return 12;
+  }
+};
+
+} /* namespace field */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_FIELD_MICROTIME_H */
+

=== modified file 'drizzled/field_conv.cc'
--- drizzled/field_conv.cc	2010-12-25 01:27:46 +0000
+++ drizzled/field_conv.cc	2011-01-04 04:05:27 +0000
@@ -189,7 +189,7 @@
     when set to NULL (TIMESTAMP fields which allow setting to NULL
     are handled by first check).
   */
-  if (field->type() == DRIZZLE_TYPE_TIMESTAMP)
+  if (field->is_timestamp())
   {
     ((field::Epoch::pointer) field)->set_time();
     return 0;					// Ok to set time to NULL
@@ -620,7 +620,7 @@
     }
     else
     {
-      if (to_field->type() == DRIZZLE_TYPE_TIMESTAMP)
+      if (to_field->is_timestamp())
       {
         do_copy= do_copy_timestamp;               // Automatic timestamp
       }

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2010-12-27 21:07:44 +0000
+++ drizzled/include.am	2011-01-04 04:05:27 +0000
@@ -87,6 +87,7 @@
 			      drizzled/field/epoch.h \
 			      drizzled/field/int32.h \
 			      drizzled/field/int64.h \
+			      drizzled/field/microtime.h \
 			      drizzled/field/null.h \
 			      drizzled/field/num.h \
 			      drizzled/field/real.h \
@@ -523,6 +524,7 @@
 			   drizzled/field/epoch.cc \
 			   drizzled/field/int32.cc \
 			   drizzled/field/int64.cc \
+			   drizzled/field/microtime.cc \
 			   drizzled/field/null.cc \
 			   drizzled/field/num.cc \
 			   drizzled/field/real.cc \

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2010-12-28 04:57:17 +0000
+++ drizzled/item.cc	2011-01-04 04:05:27 +0000
@@ -44,6 +44,7 @@
 #include "drizzled/field/epoch.h"
 #include "drizzled/field/int32.h"
 #include "drizzled/field/int64.h"
+#include "drizzled/field/microtime.h"
 #include "drizzled/field/null.h"
 #include "drizzled/field/real.h"
 #include "drizzled/field/size.h"
@@ -1065,6 +1066,7 @@
     case DRIZZLE_TYPE_DATE:
     case DRIZZLE_TYPE_DATETIME:
     case DRIZZLE_TYPE_TIMESTAMP:
+    case DRIZZLE_TYPE_MICROTIME:
       return true;
     case DRIZZLE_TYPE_BLOB:
     case DRIZZLE_TYPE_VARCHAR:
@@ -1195,8 +1197,13 @@
   case DRIZZLE_TYPE_DATE:
     field= new Field_date(maybe_null, name, &my_charset_bin);
     break;
+
+  case DRIZZLE_TYPE_MICROTIME:
+    field= new field::Microtime(maybe_null, name);
+    break;
+
   case DRIZZLE_TYPE_TIMESTAMP:
-    field= new field::Epoch(maybe_null, name, &my_charset_bin);
+    field= new field::Epoch(maybe_null, name);
     break;
   case DRIZZLE_TYPE_DATETIME:
     field= new Field_datetime(maybe_null, name, &my_charset_bin);
@@ -1400,6 +1407,7 @@
       break;
     }
   case DRIZZLE_TYPE_DATETIME:
+  case DRIZZLE_TYPE_MICROTIME:
   case DRIZZLE_TYPE_TIMESTAMP:
     {
       type::Time tm;
@@ -1637,6 +1645,7 @@
     */
     if ((type= item->field_type()) == DRIZZLE_TYPE_DATETIME ||
         type == DRIZZLE_TYPE_TIME ||
+        type == DRIZZLE_TYPE_MICROTIME ||
         type == DRIZZLE_TYPE_DATE ||
         type == DRIZZLE_TYPE_TIMESTAMP)
     {

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2010-12-29 23:38:38 +0000
+++ drizzled/join.cc	2011-01-04 04:05:27 +0000
@@ -3045,6 +3045,7 @@
           if (type == DRIZZLE_TYPE_DATE ||
               type == DRIZZLE_TYPE_TIME ||
               type == DRIZZLE_TYPE_DATETIME ||
+              type == DRIZZLE_TYPE_MICROTIME ||
               type == DRIZZLE_TYPE_TIMESTAMP)
           {
             key_length+= 8;

=== modified file 'drizzled/message.cc'
--- drizzled/message.cc	2010-12-24 06:48:40 +0000
+++ drizzled/message.cc	2011-01-04 04:05:27 +0000
@@ -50,6 +50,7 @@
 static const std::string DATE("DATE");
 static const std::string EPOCH("EPOCH");
 static const std::string TIMESTAMP("TIMESTAMP");
+static const std::string MICROTIME("MICROTIME");
 static const std::string DATETIME("DATETIME");
 static const std::string TIME("TIME");
 static const std::string UUID("UUID");
@@ -140,6 +141,7 @@
   case message::Table::Field::ENUM:
   case message::Table::Field::DATE:
   case message::Table::Field::EPOCH:
+  case message::Table::Field::MICROTIME:
   case message::Table::Field::DATETIME:
   case message::Table::Field::TIME:
   case message::Table::Field::UUID:
@@ -174,6 +176,8 @@
     return DATE;
   case message::Table::Field::EPOCH:
     return TIMESTAMP;
+  case message::Table::Field::MICROTIME:
+    return MICROTIME;
   case message::Table::Field::DATETIME:
     return DATETIME;
   case message::Table::Field::TIME:
@@ -209,6 +213,8 @@
     return DATE;
   case message::Table::Field::EPOCH:
     return EPOCH;
+  case message::Table::Field::MICROTIME:
+    return MICROTIME;
   case message::Table::Field::DATETIME:
     return DATETIME;
   case message::Table::Field::TIME:

=== modified file 'drizzled/message/statement_transform.cc'
--- drizzled/message/statement_transform.cc	2010-12-24 16:11:53 +0000
+++ drizzled/message/statement_transform.cc	2011-01-04 04:05:27 +0000
@@ -1373,6 +1373,9 @@
   case Table::Field::EPOCH:
     destination.append(" TIMESTAMP",  10);
     break;
+  case Table::Field::MICROTIME:
+    destination.append(" MICROTIME",  10);
+    break;
   case Table::Field::DATETIME:
     destination.append(" DATETIME",  9);
     break;
@@ -1408,8 +1411,10 @@
   {
     destination.append(" NOT NULL", 9);
   }
-  else if (field.type() == Table::Field::EPOCH)
+  else if (field.type() == Table::Field::EPOCH or field.type() == Table::Field::MICROTIME)
+  {
     destination.append(" NULL", 5);
+  }
 
   if (field.type() == Table::Field::INTEGER || 
       field.type() == Table::Field::BIGINT)
@@ -1495,6 +1500,8 @@
     return Table::Field::INTEGER; /* unreachable */
   case DRIZZLE_TYPE_TIMESTAMP:
     return Table::Field::EPOCH;
+  case DRIZZLE_TYPE_MICROTIME:
+    return Table::Field::MICROTIME;
   case DRIZZLE_TYPE_LONGLONG:
     return Table::Field::BIGINT;
   case DRIZZLE_TYPE_DATETIME:

=== modified file 'drizzled/message/table.proto'
--- drizzled/message/table.proto	2010-12-30 18:10:25 +0000
+++ drizzled/message/table.proto	2011-01-04 04:05:27 +0000
@@ -79,6 +79,7 @@
       UUID = 11;
       TIME = 12;
       BOOLEAN = 13;
+      MICROTIME = 14;
     }
 
     message FieldOptions {

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2010-12-24 07:15:43 +0000
+++ drizzled/sql_load.cc	2011-01-04 04:05:27 +0000
@@ -485,7 +485,7 @@
                             ER_WARN_TOO_FEW_RECORDS,
                             ER(ER_WARN_TOO_FEW_RECORDS), session->row_count);
 
-        if (!field->maybe_null() && field->type() == DRIZZLE_TYPE_TIMESTAMP)
+        if (not field->maybe_null() and field->is_timestamp())
             ((field::Epoch::pointer) field)->set_time();
       }
       else
@@ -602,9 +602,9 @@
             return(1);
           }
           field->set_null();
-          if (!field->maybe_null())
+          if (not field->maybe_null())
           {
-            if (field->type() == DRIZZLE_TYPE_TIMESTAMP)
+            if (field->is_timestamp())
             {
               ((field::Epoch::pointer) field)->set_time();
             }
@@ -672,7 +672,7 @@
                      session->row_count);
             return(1);
           }
-          if (!field->maybe_null() && field->type() == DRIZZLE_TYPE_TIMESTAMP)
+          if (not field->maybe_null() and field->is_timestamp())
               ((field::Epoch::pointer) field)->set_time();
           /*
             QQ: We probably should not throw warning for each field.

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2010-12-31 06:43:08 +0000
+++ drizzled/sql_parse.cc	2011-01-04 04:05:27 +0000
@@ -827,7 +827,7 @@
     */
     if (default_value->type() == Item::FUNC_ITEM &&
         !(((Item_func*)default_value)->functype() == Item_func::NOW_FUNC &&
-         type == DRIZZLE_TYPE_TIMESTAMP))
+         (type == DRIZZLE_TYPE_TIMESTAMP or type == DRIZZLE_TYPE_MICROTIME)))
     {
       my_error(ER_INVALID_DEFAULT, MYF(0), field_name->str);
       return true;
@@ -849,7 +849,7 @@
     }
   }
 
-  if (on_update_value && type != DRIZZLE_TYPE_TIMESTAMP)
+  if (on_update_value && (type != DRIZZLE_TYPE_TIMESTAMP and type != DRIZZLE_TYPE_MICROTIME))
   {
     my_error(ER_INVALID_ON_UPDATE, MYF(0), field_name->str);
     return true;

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2010-12-24 07:15:43 +0000
+++ drizzled/sql_table.cc	2011-01-04 04:05:27 +0000
@@ -472,23 +472,21 @@
     sql_field->length= 8; // Unireg field length
     (*blob_columns)++;
     break;
-  case DRIZZLE_TYPE_VARCHAR:
-    break;
+
   case DRIZZLE_TYPE_ENUM:
-    if (check_duplicates_in_interval("ENUM",
-                                     sql_field->field_name,
-                                     sql_field->interval,
-                                     sql_field->charset,
-                                     &dup_val_count))
-      return 1;
-    break;
-  case DRIZZLE_TYPE_DATE:  // Rest of string types
-  case DRIZZLE_TYPE_TIME:
-  case DRIZZLE_TYPE_DATETIME:
-  case DRIZZLE_TYPE_NULL:
-    break;
-  case DRIZZLE_TYPE_DECIMAL:
-    break;
+    {
+      if (check_duplicates_in_interval("ENUM",
+				       sql_field->field_name,
+				       sql_field->interval,
+				       sql_field->charset,
+				       &dup_val_count))
+      {
+	return 1;
+      }
+    }
+    break;
+
+  case DRIZZLE_TYPE_MICROTIME:
   case DRIZZLE_TYPE_TIMESTAMP:
     /* We should replace old TIMESTAMP fields with their newer analogs */
     if (sql_field->unireg_check == Field::TIMESTAMP_OLD_FIELD)
@@ -504,11 +502,25 @@
       }
     }
     else if (sql_field->unireg_check != Field::NONE)
+    {
       (*timestamps_with_niladic)++;
+    }
 
     (*timestamps)++;
-    /* fall-through */
-  default:
+
+    break;
+
+  case DRIZZLE_TYPE_BOOLEAN:
+  case DRIZZLE_TYPE_DATE:  // Rest of string types
+  case DRIZZLE_TYPE_DATETIME:
+  case DRIZZLE_TYPE_DECIMAL:
+  case DRIZZLE_TYPE_DOUBLE:
+  case DRIZZLE_TYPE_LONG:
+  case DRIZZLE_TYPE_LONGLONG:
+  case DRIZZLE_TYPE_NULL:
+  case DRIZZLE_TYPE_TIME:
+  case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_VARCHAR:
     break;
   }
 

=== modified file 'drizzled/table_proto_write.cc'
--- drizzled/table_proto_write.cc	2010-12-25 04:38:28 +0000
+++ drizzled/table_proto_write.cc	2011-01-04 04:05:27 +0000
@@ -299,6 +299,7 @@
         if (field_arg->sql_type == DRIZZLE_TYPE_DATE
             || field_arg->sql_type == DRIZZLE_TYPE_TIME
             || field_arg->sql_type == DRIZZLE_TYPE_DATETIME
+            || field_arg->sql_type == DRIZZLE_TYPE_MICROTIME
             || field_arg->sql_type == DRIZZLE_TYPE_TIMESTAMP)
         {
           type::Time ltime;

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2010-12-27 19:41:48 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2011-01-04 04:05:27 +0000
@@ -3850,6 +3850,7 @@
       return(DATA_VARMYSQL);
     }
   case DRIZZLE_TYPE_DECIMAL:
+  case DRIZZLE_TYPE_MICROTIME:
     return(DATA_FIXBINARY);
   case DRIZZLE_TYPE_LONG:
   case DRIZZLE_TYPE_LONGLONG:

=== modified file 'plugin/mysql_protocol/mysql_protocol.cc'
--- plugin/mysql_protocol/mysql_protocol.cc	2010-12-24 06:48:40 +0000
+++ plugin/mysql_protocol/mysql_protocol.cc	2011-01-04 04:05:27 +0000
@@ -543,6 +543,10 @@
         pos[6]= 15;
         break;
 
+      case DRIZZLE_TYPE_MICROTIME:
+        pos[6]= 15;
+        break;
+
       case DRIZZLE_TYPE_UUID:
         pos[6]= 15;
         break;

=== modified file 'tests/r/metadata.result'
--- tests/r/metadata.result	2010-12-20 19:13:40 +0000
+++ tests/r/metadata.result	2011-01-04 04:05:27 +0000
@@ -15,7 +15,7 @@
 def	test	t1	t1	b	b	1	11	0	Y	32768	0	63
 def	test	t1	t1	c	c	1	11	0	Y	32768	0	63
 def	test	t1	t1	d	d	1	11	0	Y	32768	0	63
-def	test	t1	t1	e	e	5	20	0	Y	32768	0	63
+def	test	t1	t1	e	e	5	21	0	Y	32768	0	63
 def	test	t1	t1	f	f	2	3	0	Y	32768	2	63
 def	test	t1	t1	g	g	2	4	0	Y	32768	3	63
 def	test	t1	t1	h	h	9	7	0	Y	0	4	63

=== modified file 'tests/r/show_check.result'
--- tests/r/show_check.result	2010-12-24 08:41:24 +0000
+++ tests/r/show_check.result	2011-01-04 04:05:27 +0000
@@ -29,7 +29,7 @@
 def	data_dictionary	show_indexes	SHOW_INDEXES	Table	Table	8	1024	2	N	4097	0	45
 def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	8	1	3	N	4097	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Key_name	Key_name	8	1024	7	N	4097	0	45
-def	data_dictionary	show_indexes	SHOW_INDEXES	Seq_in_index	Seq_in_index	5	20	1	N	36865	0	63
+def	data_dictionary	show_indexes	SHOW_INDEXES	Seq_in_index	Seq_in_index	5	21	1	N	36865	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Column_name	Column_name	8	1024	1	N	4097	0	45
 Table	Unique	Key_name	Seq_in_index	Column_name
 t1	YES	PRIMARY	1	a
@@ -65,7 +65,7 @@
 Variable_name	Value
 show table status from test like "this_doesn't_exists%";
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
-def	data_dictionary	show_table_status	SHOW_TABLE_STATUS	Session	Session	5	20	0	N	36865	0	63
+def	data_dictionary	show_table_status	SHOW_TABLE_STATUS	Session	Session	5	21	0	N	36865	0	63
 def	data_dictionary	show_table_status	SHOW_TABLE_STATUS	Schema	Schema	8	1024	0	N	4097	0	45
 def	data_dictionary	show_table_status	SHOW_TABLE_STATUS	Name	Name	8	1024	0	N	4097	0	45
 def	data_dictionary	show_table_status	SHOW_TABLE_STATUS	Type	Type	8	1024	0	N	4097	0	45
@@ -449,7 +449,7 @@
 def	data_dictionary	show_indexes	SHOW_INDEXES	Table	Table	8	1024	2	N	4097	0	45
 def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	8	1	3	N	4097	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Key_name	Key_name	8	1024	7	N	4097	0	45
-def	data_dictionary	show_indexes	SHOW_INDEXES	Seq_in_index	Seq_in_index	5	20	1	N	36865	0	63
+def	data_dictionary	show_indexes	SHOW_INDEXES	Seq_in_index	Seq_in_index	5	21	1	N	36865	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Column_name	Column_name	8	1024	6	N	4097	0	45
 Table	Unique	Key_name	Seq_in_index	Column_name
 t1	YES	PRIMARY	1	field1

